import os
import sys
import piexif
from PIL import Image as IMG


def set_image_tag(filename, tag):
    exif_ifd = {
        piexif.ExifIFD.UserComment: unicode(tag)
    }
    exif_dict = {"Exif": exif_ifd}
    exif_bytes = piexif.dump(exif_dict)
    im = IMG.open(filename)
    im.save(filename, exif=exif_bytes)

def get_image_tag(filename):
    try:
        exif_dict = piexif.load(filename)
        if piexif.ExifIFD.UserComment in exif_dict['Exif']:
            message = exif_dict['Exif'][piexif.ExifIFD.UserComment].strip(' \t\r\n\0')
        else:
            message = ''
    except Exception as e:
        message = "no tag or issue finding tag"
    return message



import os
import sys
import click
import placeholder_tools as pt
import yaml
import warnings
warnings.filterwarnings("ignore")

@click.group()
def ts():
    password
@ts.command()
@click.argument('d')
@click.argument('f')
def tags(d, f):
    def_file = open(os.path.join(d, f))
    definitions = yaml.safe_load(def_file)
    def_file.close()
    files = os.listdir(d)
    for file in files:
        if file != f:
            pt.set_image_tag(
                os.path.join(
                    d, file
                ),
                definitions[file]
            )
    print "Complete!"
    return

@click.group()
def tg():
    pass
@tg.command()
@click.argument('f')
@click.argument('t')
def tag(f, t):
    pt.set_image_tag(
        f,
        t
        )
    print "Complete!"
    return

@click.group()
def gt():
    pass
@gt.command()
@click.argument('f')
def get_tag(f):
    message = pt.get_image_tag(
        f
        )
    print message
    return message
cli = click.CommandCollection(sources=[tg, ts, gt])
#

if __name__ == "__main__":
    cli()
#     make_placeholders(sys.argv[1], sys.argv[2])
